/* SAS 9.1 for Windows  */

/* Diese Datei: Beisp_04.sas 
   (03.03.2009) */

/* Beispiel 4: Gruppenvergleiche 

Quelle:
Schimpl-Neimanns, Bernhard: Schtzung des Stichprobenfehlers im 
Mikrozensus mit Stata - Eine Einfhrung mit Beispielen zum Campus 
File Mikrozensus 2002. GESIS-Methodenbericht 2009/02. Mannheim: GESIS.
URL: http://www.gesis.org/fileadmin/upload/forschung/publikationen/
     gesis_reihen/gesis_methodenberichte/2009/gesis_mb_09_02.pdf
Diese Datei:
     http://www.gesis.org/dienstleistungen/tools-standards/mikrodaten-tools/
     sp-fehler/SAS_Beispiele.zip

*/


libname library '<Arbeitsverzeichnis>' ;
libname cf '<Arbeitsverzeichnis>' ;


/* Datendefinition */
data  cf.temp ;
  set cf.mz02cf_Beisp (keep = ef1 ef3 ef30 ef504 ef505 ef708 ef712) ;
             /* Schichtung: Bundesland (ef1) x Geb.schicht (ef712) */
     schicht = ef1*10 + ef712;
            /* Auswahlsatz: MZ 1%, CF 3,5% */
     f = 0.01 * 0.035;
            /* Designgewicht */
     w = 1/f;             
            /* ILO-Erwerbslos */
     y = (ef504 eq 2);
            /* Subpopulation: Bev. am Hauptwohns. (ef505), 
                  15-65 Jahre (ef30), Erwerbspersonen (ef504) */
     sub = (ef505<=2 & ef30>=15 & ef30<=65 & ef504<=2);
            /* West-/Ostdeutschland */
     if (ef1>=1 & ef1<=11 & ef708 ne 9) then westost=1;
     if (ef1>11 | ef708=9) then westost=2;
run;

proc sort data=cf.temp;
   by westost;
run;


/* Designbasierte Schtzung mit SURVEYMEANS
   R       Auswahlsatz f (s.o.) fr Endlichkeitskorrektur
   SUM     Anforderung von Gesamtwerten
   CLSUM   Anforderung Konfidenzintervall
Design
   STRATA  geschichtete
   CLUSTER einstufige Klumpenstichprobe 
   DOMAIN  Schtzung des Gesamtwertes (y) fr die Subpopulation (sub)
- kein Chi Test
*/
PROC SURVEYMEANS DATA = cf.temp R=0.00035 SUM CLSUM;
   STRATA  schicht;
   VAR     y ;
   CLASS   y sub westost; 
   DOMAIN  sub * westost;
   CLUSTER ef3;
   WEIGHT  w;
RUN;
/* Ergebnis  Domain Analysis: sub*westost
sub   westost  Variable  Level       Sum       Std Dev      95% CL for Sum
------------------------------------------------------------------------------
  1         1  y         1        1677143         72162   1535691.1  1818594.6
            2  y         1        1197143         61777   1076047.9  1318237.8
*/

/* Alternativ */
PROC SURVEYFREQ DATA=cf.temp (keep=y sub westost w ef3 schicht) RATE=0.00035;
     TABLES  sub* y * westost  / CHISQ COL ;  
     STRATA  schicht;
     CLUSTER ef3;
     WEIGHT  w; 
run;
/* Ergebnis
Beachte: Chi-Quadrat-Teststatistik weicht von Stata-Ergebnis leicht ab.

The SURVEYFREQ Procedure - Table of y by westost - Controlling for sub=1

              Weighted  Std Dev of   Column   Std Err of
y  westost   Frequency    Wgt Freq  Percent  Col Percent
 --------------------------------------------------------
1        1     1677143       72162   6.1267      0.2577
         2     1197143       61777  18.1621      0.8669


                    Rao-Scott Chi-Square Test
               Pearson Chi-Square    735.1681
               Design Correction       2.4367

               Rao-Scott Chi-Square  301.7070
               DF                           1
               Pr > ChiSq              <.0001

                          Sample Size = 25137
*/
