/* SAS 9.1 for Windows  */

/* Diese Datei: Beisp_05.sas 
   (09.03.2009) */

/* Beispiel 5: Gesamtwerte mit gebundener Hochrechnung (Poststratifikation) 

Quelle:
Schimpl-Neimanns, Bernhard: Schtzung des Stichprobenfehlers im 
Mikrozensus mit Stata - Eine Einfhrung mit Beispielen zum Campus 
File Mikrozensus 2002. GESIS-Methodenbericht 2009/02. Mannheim: GESIS.
URL: http://www.gesis.org/fileadmin/upload/forschung/publikationen/
     gesis_reihen/gesis_methodenberichte/2009/gesis_mb_09_02.pdf
Diese Datei:
     http://www.gesis.org/dienstleistungen/tools-standards/mikrodaten-tools/
     sp-fehler/SAS_Beispiele.zip

*/


libname library '<Arbeitsverzeichnis>' ;
libname cf '<Arbeitsverzeichnis>' ;


/* Datendefinition */
data  cf.temp ;
  set cf.mz02cf_Beisp (keep=ef1 ef3 ef30 ef32 ef52 ef127 ef504 ef505 ef712 ef750g);
          /* Schichtung: Bundesland (ef1) x Geb.schicht (ef712) */
     schicht = ef1*10 + ef712;
         /* Auswahlsatz: MZ 1%, CF 3,5% */
     f = 0.01 * 0.035;
         /* Designgewicht */
     w = 1/f;             
	/* Subpopulation: Bev. am Hauptwohns. (ef505), 
               15+ Jahre (ef30) */
     sub = (ef505<=2 & ef30>=15);
        /* ILO-Erwerbslos */
     y = (ef504 eq 2 & sub eq 1);  /* mit Bercksichtigung Subpopulation */
     x = (ef504 eq 2);             /* ohne Bercksichtigung Subpopulation */
        /* Anpassungsklassen: Geschl. x Staatsangeh., Sold., Wehrpfl. */
     if (ef32=1 & ef52=1 & ef127 ne 9 & ef127 ne 10) then anp=1; /* Deutsche Mnner */
     if (ef32=2 & ef52=1) then anp=2;                            /* Deutsche Frauen */
     if (ef32=1 & ef52 ne 1) then anp=3;                         /* Ausl. Mnner */
     if (ef32=2 & ef52 ne 1) then anp=4;                         /* Ausl. Frauen */
     if (ef32=1 & ef52=1 & ef127=9) then anp=5;                  /* Soldaten */
     if (ef32=1 & ef52=1 & ef127=10) then anp=6;                 /* Wehrpflichtige */
            /* Proxy Anpassungsschicht Bundesland x anp  
                      (extra Schicht fr sub=0) */
     anpschicht = sub*(ef1*10+anp) ;
        /* Hochrechnungsfaktor f. Population und Bev. am Hauptwohnsitz */
     w_anp   = ef750g*100*(ef505<=2); 
     w_sub   = w * sub;
     wysub   = w * sub * y;
        /* Satznummer */
     id = _n_ ;
run;

proc sort data = cf.temp (keep = anpschicht w_anp w_sub wysub) out = cf.POP;
		  by anpschicht;
run;

proc sort data = cf.temp; 
     by anpschicht; 
run;
        

/* Populationsdaten pro Anpassungsschicht 
         Definition cf.POP: 87 x 4  
         Spalte 1-4: anpschicht, _TYPE_, _FREQ_, M_k
*/
proc means data=cf.POP noprint ;
     var w_anp w_sub wysub;         
     by anpschicht;   
     output out=cf.POP sum = M_k  M_Dach_k Y_Dach_k;   /* _TOTAL_ = M_k */
run;

data cf.tempPOP;
   merge cf.temp cf.POP;
   by anpschicht;
run;

proc sort data = cf.tempPOP;
     by id;
run;


data cf.tempPOP2;
   set cf.tempPOP ;
   w_post = 0;  /* Gewichtungsvariable fr gebundene Hochrechnung */
   if (M_Dach_k>0) then w_post = (M_k / M_Dach_k) * w ; 
   z = 0;      /* Hilfsvariable fr Varianzschtzung */
   if (M_Dach_k>0) then z = sub * (M_k/M_Dach_k)*(y-(Y_Dach_k/M_Dach_k)); 
run;


/* [1] Gewichteter Gesamtwert Poststratifikation */
proc freq data=cf.tempPOP2 ;
  table y * sub;
  weight w_post ; 
run;
/* Ergebnis (y=1 & sub=1): 3428499 */


/* [2] Varianz zu [1] Poststratifikation*/
proc surveymeans data=cf.tempPOP2 RATE=0.00035 sum ; 
   strata schicht;
   cluster ef3;
   var    z;
   domain sub;
   weight w;
run;
/*  Ergebnis: Std.Dev. = 111236 */

quit
