/* SAS 9.1 for Windows  */

/* Diese Datei: Beisp_09.sas 
   (26.03.2009) */

/* 
==============================================================================
Beispiel 9: Durchschnittliche Arbeitsstunden (Designgewichtung) 
==============================================================================

Quelle:
Schimpl-Neimanns, Bernhard: Schtzung des Stichprobenfehlers im 
Mikrozensus mit Stata - Eine Einfhrung mit Beispielen zum Campus 
File Mikrozensus 2002. GESIS-Methodenbericht 2009/02. Mannheim: GESIS.
URL: http://www.gesis.org/fileadmin/upload/forschung/publikationen/
     gesis_reihen/gesis_methodenberichte/2009/gesis_mb_09_02.pdf
Diese Datei:
     http://www.gesis.org/dienstleistungen/tools-standards/mikrodaten-tools/
     sp-fehler/SAS_Beispiele.zip

*/



libname library '<Arbeitsverzeichnis>' ;
libname cf '<Arbeitsverzeichnis>' ;


/* Datendefinition */
data  cf.temp ;
  set cf.mz02cf_Beisp (keep = ef1 ef3 ef32 ef141 ef504 ef505 ef708 ef712) ;
             /* Schichtung: Bundesland (ef1) x Geb.schicht (ef712) */
     schicht = ef1*10 + ef712;
            /* Auswahlsatz: MZ 1%, CF 3,5% */
     f = 0.01 * 0.035;
            /* Designgewicht */
     w = 1/f;             
          /* Subpopulation: Bevlkerung am Hauptwohnsitz, Erwerbsttige */
     sub = (ef505<=2 & ef504=1);
	            /* Region */
     if (ef1>=1 & ef1<=11 & ef708 ne 9) then westost=1; /* West, West-Berlin */
     if (ef1>11 | ef708=9) then westost=2;              /* Ost, Ost-Berlin */
	     /* ef141 Normalerw. geleist. Arbeitszeit (Std.) je Woche. */
     y = ef141;   /* Rekodierung vergrberter Werte auf Klassenmitte */
     if (ef141=57) then y=58; 
     if (ef141=60) then y=62;
     if (ef141=65) then y=67;
     if (ef141=70) then y=72;
     if (ef141=75) then y=77;
     if (ef141=80) then y=82;
     if (ef141=85) then y=87;
     if (ef141=90) then y=93.5;
run;



/* Stichprobendesign: SRSWR, Designgewichtung, Schichtung, Klumpung 
   Durchschnittliche Arbeitsstunden nach Geschlecht und Region  */
PROC SURVEYMEANS DATA = cf.temp (keep = schicht ef3 y sub w ef32 westost) R=0.00035 MEAN;
   STRATA  schicht;
   CLUSTER ef3;
   WEIGHT  w;
   VAR y ; 
   CLASS   sub ef32 westost;  
   DOMAIN  sub * westost * ef32;
RUN;
/* SAS-Ergebnis - Domain Analysis: EF32 Geschlecht*sub*westost
EF32                                                  Std Error
Geschlecht         sub     westost         Mean         of Mean
Mnnlich             1           1    40.742352        0.162904
Weiblich             1           1    40.210366        0.279308
Mnnlich             1           2    30.864484        0.216072
Weiblich             1           2    35.289011        0.329392
*/

