/* SAS 9.1 for Windows  */

/* Diese Datei: Beisp_11.sas 
   (27.03.2009) */

/* 
==============================================================================
Beispiel 11: Regression des Monatsnettoeinkommens auf Bildung, Geschlecht und 
             Staatsangehrigkeit                                      
==============================================================================

Quelle:
Schimpl-Neimanns, Bernhard: Schtzung des Stichprobenfehlers im 
Mikrozensus mit Stata - Eine Einfhrung mit Beispielen zum Campus 
File Mikrozensus 2002. GESIS-Methodenbericht 2009/02. Mannheim: GESIS.
URL: http://www.gesis.org/fileadmin/upload/forschung/publikationen/
     gesis_reihen/gesis_methodenberichte/2009/gesis_mb_09_02.pdf
Diese Datei:
     http://www.gesis.org/dienstleistungen/tools-standards/mikrodaten-tools/
     sp-fehler/SAS_Beispiele.zip

*/


libname library '<Arbeitsverzeichnis>' ;
libname cf '<Arbeitsverzeichnis>' ;


/* Datendefinition */
data  cf.temp ;
  set cf.mz02cf_Beisp (keep = ef1 ef3 ef4 ef30 ef32 ef52 ef127 ef286 ef287 ef288 
                         ef289 ef338 ef372 ef504 ef505 ef708 ef712 ef750g) ;
             /* Allgemeiner Bildungsabschluss - typische Ausbildungsdauer */
     if (ef287=1) then x287=9;              /* Hauptschule */
     if (ef287=2 | ef287=3) then x287=10;   /* Realschule, POS */
     if (ef287=4) then x287=12;             /* FHR */
     if (ef287=5) then x287=13;             /* Abitur */
     if (ef287=0) then x287=8;              /* ohne Abschluss */
     if (ef287=9 | ef286=0 | ef286=9) then x287=.;  /* k.A., Entfllt */
             /* Beruflicher Abschluss - typische Ausbildungsdauer */
     if (ef289=0) then x289=0;             /* ohne Abschluss */
     if (ef289=1 | ef289=2) then x289=1;   /* Anlernausb., BVJ */
     if (ef289=3 | ef289=7 | ef289=8) then x289=3; /* Lehre, FH, Verw.FH */
     if (ef289=4 | ef289=5 | ef289=6) then x289=2; /* BFS, Meister, FS DDR */
     if (ef289=9) then x289=5;             /* Uni */
     if (ef289=10) then x289=7;            /* Prom. */
     if (ef289=99 | ef288=0 | ef288=9) then x289=.; /* k.A., Entfllt */
	         /* Rekodierung Nettoeinkommen - Klassenmitte bzw. obere 
	            Randklasse  = 150% * Untergrenze */
     if (ef372=1) then v372m=75;
     if (ef372=2) then v372m=225;
     if (ef372=3) then v372m=400;
     if (ef372=4) then v372m=600;
     if (ef372=5) then v372m=800;
     if (ef372=6) then v372m=1000;
     if (ef372=7) then v372m=1200;
     if (ef372=8) then v372m=1400;
     if (ef372=9) then v372m=1600;
     if (ef372=10) then v372m=1850;
     if (ef372=11) then v372m=2150;
     if (ef372=12) then v372m=2450;
     if (ef372=13) then v372m=2750;
     if (ef372=14) then v372m=3050;
     if (ef372=15) then v372m=3400;
     if (ef372=16) then v372m=3800;
     if (ef372=17) then v372m=4250;
     if (ef372=18) then v372m=4750;
     if (ef372=19) then v372m=5250;
     if (ef372=20) then v372m=5750;
     if (ef372=21) then v372m=6750;
     if (ef372=22) then v372m=8750;
     if (ef372=23) then v372m=14000;
     if (ef372=24) then v372m=27000;
     if (ef372=50 | ef372=90 | ef372=99) then v372m=.;
     logv372m = log(v372m);
             /* Geschlecht 1=weiblich */
	 if (ef32=1) then v32=0;
     if (ef32=2) then v32=1;
             /* Staatsangehrigkeit 1=Auslnder */
	 if (ef52=1) then v52=0;
     if (ef52 ne 1) then v52=1;
	 	 /* Subpopulation: Bevlkerung am Hauptwohnsitz (ef505), 
	          Abh. Beschftigte (ohne Azubis) (ef127), Erwerbsttige (ef504), 
	          berw. Lebensunterhalt (ef338) = Erwerbsttigk., gltige 
	          Einkommensangaben (ef372), gltige Angaben allg. 
	          Bildungsabschluss (x287), gltige Angaben berufl. Abschluss 
	          (x289) */ 
     if (ef505>=1 & ef505<=2 & ef127>=4 & ef127<=6 & ef504=1 & ef338=1 & 
         ef372>=1 & ef372<=24 & x287>=8 & x287<=13 & x289>=0 & x289<=7) 
         then sub=1; 
     if (sub=.) then logv372m=.;
run;


/* (1) OLS (SRSWR) */
proc reg data=cf.temp (keep = sub logv372m x287 x289 v32 v52) ;
     where sub=1;
     model logv372m = x287 x289 v32 v52 ;
run;  
quit;
/* Ergebnis
R-Square     0.2750
                      Parameter      Standard
Variable     DF       Estimate          Error 
Intercept     1        6.40652        0.04039 
x287          1        0.07767        0.00418 
x289          1        0.08377        0.00514 
v32           1       -0.49540        0.01185 
v52           1       -0.05103        0.02561 
*/



/* (2) Robuste Varianzschtzung, Klumpung: Auswahlbezirk (SRSWR) */
proc surveyreg data=cf.temp  (keep = sub ef3 logv372m x287 x289 v32 v52) RATE=0.00035;
 CLUSTER ef3;
 where sub=1;
 MODEL logv372m = x287 x289 v32 v52 ;
run;
quit;
/* Ergebnis
R-square    0.2750
Estimated Regression Coefficients
                             Standard
Parameter      Estimate         Error
Intercept     6.4065164    0.04294099
x287          0.0776718    0.00478330
x289          0.0837698    0.00617394
v32          -0.4954015    0.01235243
v52          -0.0510304    0.02569130
*/
